JsAgent

Struct JsAgent 

pub struct JsAgent(/* private fields */);

Implementations

Source

impl JsAgent

pub fn to_js_string(&self) -> String

pub fn is_individual(&self) -> bool

pub fn is_group(&self) -> bool

pub fn is_document(&self) -> bool

pub fn id(&self) -> JsIdentifier

pub async fn key_ops(&self) -> Result<Map, JsSerializationError>

Returns prekey operations for this agent as a Map of hash -> serialized bytes for StaticEvent

pub async fn key_op_hashes(&self) -> Vec<Uint8Array>

Returns prekey operation hashes for this Agent as an array of hash bytes.

Methods from Deref<Target = Agent<JsSigner, JsChangeId, JsEventHandler>>

pub fn id(&self) -> Identifier

pub fn agent_id(&self) -> AgentId

pub async fn individual_ids(&self) -> HashSet<IndividualId>

pub async fn pick_individual_prekeys( &self, doc_id: DocumentId, ) -> HashMap<IndividualId, ShareKey>

pub async fn key_ops(&self) -> CaMap<KeyOp>